==> aliyun-java-sdk-kms-2.10.1-sources.jar: com/aliyuncs/kms/model/v20160120/UpdateSecretVersionStageRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.kms.model.v20160120;

import com.aliyuncs.RpcAcsRequest;
import com.aliyuncs.http.ProtocolType;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.kms.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class UpdateSecretVersionStageRequest extends RpcAcsRequest<UpdateSecretVersionStageResponse> {
	   

	private String removeFromVersion;

	private String moveToVersion;

	private String versionStage;

	private String secretName;
	public UpdateSecretVersionStageRequest() {
		super("Kms", "2016-01-20", "UpdateSecretVersionStage", "kms");
		setProtocol(ProtocolType.HTTPS);
		setMethod(MethodType.POST);
		try {
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointMap").set(this, Endpoint.endpointMap);
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	public String getRemoveFromVersion() {
		return this.removeFromVersion;
	}

	public void setRemoveFromVersion(String removeFromVersion) {
		this.removeFromVersion = removeFromVersion;
		if(removeFromVersion != null){
			putQueryParameter("RemoveFromVersion", removeFromVersion);
		}
	}

	public String getMoveToVersion() {
		return this.moveToVersion;
	}

	public void setMoveToVersion(String moveToVersion) {
		this.moveToVersion = moveToVersion;
		if(moveToVersion != null){
			putQueryParameter("MoveToVersion", moveToVersion);
		}
	}

	public String getVersionStage() {
		return this.versionStage;
	}

	public void setVersionStage(String versionStage) {
		this.versionStage = versionStage;
		if(versionStage != null){
			putQueryParameter("VersionStage", versionStage);
		}
	}

	public String getSecretName() {
		return this.secretName;
	}

	public void setSecretName(String secretName) {
		this.secretName = secretName;
		if(secretName != null){
			putQueryParameter("SecretName", secretName);
		}
	}

	@Override
	public Class<UpdateSecretVersionStageResponse> getResponseClass() {
		return UpdateSecretVersionStageResponse.class;
	}

}

==> aliyun-java-sdk-kms-2.11.0-sources.jar: com/aliyuncs/kms/model/v20160120/UpdateSecretVersionStageRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.kms.model.v20160120;

import com.aliyuncs.RpcAcsRequest;
import com.aliyuncs.http.ProtocolType;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.kms.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class UpdateSecretVersionStageRequest extends RpcAcsRequest<UpdateSecretVersionStageResponse> {
	   

	private String removeFromVersion;

	private String moveToVersion;

	private String versionStage;

	private String secretName;
	public UpdateSecretVersionStageRequest() {
		super("Kms", "2016-01-20", "UpdateSecretVersionStage", "kms-service");
		setProtocol(ProtocolType.HTTPS);
		setMethod(MethodType.POST);
		try {
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointMap").set(this, Endpoint.endpointMap);
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	public String getRemoveFromVersion() {
		return this.removeFromVersion;
	}

	public void setRemoveFromVersion(String removeFromVersion) {
		this.removeFromVersion = removeFromVersion;
		if(removeFromVersion != null){
			putQueryParameter("RemoveFromVersion", removeFromVersion);
		}
	}

	public String getMoveToVersion() {
		return this.moveToVersion;
	}

	public void setMoveToVersion(String moveToVersion) {
		this.moveToVersion = moveToVersion;
		if(moveToVersion != null){
			putQueryParameter("MoveToVersion", moveToVersion);
		}
	}

	public String getVersionStage() {
		return this.versionStage;
	}

	public void setVersionStage(String versionStage) {
		this.versionStage = versionStage;
		if(versionStage != null){
			putQueryParameter("VersionStage", versionStage);
		}
	}

	public String getSecretName() {
		return this.secretName;
	}

	public void setSecretName(String secretName) {
		this.secretName = secretName;
		if(secretName != null){
			putQueryParameter("SecretName", secretName);
		}
	}

	@Override
	public Class<UpdateSecretVersionStageResponse> getResponseClass() {
		return UpdateSecretVersionStageResponse.class;
	}

}
